@@ -1,2 +1,2 @@
-def sub_one(number):
+def Sub_one(number):
     return number - 1
\ No newline at end of file
